Project Description
===================

Texnew is an automatic LaTeX template management module and command line
tool. With it, you can automatically build pre-defined templates and
update existing LaTeX files.

The module provides generic objects useful for representing LaTeX
documents as python objects.

For more detailed information, see the `Tenxew
Github <https://github.com/alexrutar/texnew>`__.
